@@ -99,7 +99,7 @@ class SpatialMappingConversionStage(Stage):
             limited_user_spatial_mapping[spatial_dim_name] = (loop_dim_unrolled, loop_size_unrolled)
 
         user_spatial_mapping_for_log = {array_dim: (loop_dim, f"{loop_size:.2f}") for (array_dim, (loop_dim, loop_size)) in limited_user_spatial_mapping.items()}
-        logger.info(f"User-provided spatial mapping converted to: {user_spatial_mapping_for_log}")
+        logger.debug(f"User-provided spatial mapping converted to: {user_spatial_mapping_for_log}")
 
         spatial_mapping_dict = {}
         layer_to_mem_op = self.layer.memory_operand_links
